@@ -22,10 +22,11 @@ NULL
 #' @param value a scalar integer
 #'
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_seed
 #' @export
 bedrock_random_seed <- function(value) {
-    value <- as.integer(value)
-    .Call(Cmcpe_random_seed, value)
+  value <- as.integer(value)
+  .Call(R_mcpe_random_seed, value)
 }
 
 #' @description
@@ -35,9 +36,10 @@ bedrock_random_seed <- function(value) {
 #' @param new_state a raw vector
 #'
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_state
 #' @export
 bedrock_random_state <- function(new_state = NULL) {
-    invisible(.Call(Cmcpe_random_state, new_state))
+  invisible(.Call(R_mcpe_random_state, new_state))
 }
 
 #' @description
@@ -50,14 +52,15 @@ bedrock_random_state <- function(new_state = NULL) {
 #' the default range is used.
 #'
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_get_uint
 #' @export
 
 bedrock_random_get_uint <- function(n, max) {
-    n <- as.integer(n)
-    if (missing(max)) {
-        max <- NULL
-    }
-    .Call(Cmcpe_random_get_uint, n, max)
+  n <- as.integer(n)
+  if (missing(max)) {
+    max <- NULL
+  }
+  .Call(R_mcpe_random_get_uint, n, max)
 }
 
 #' @description
@@ -65,22 +68,23 @@ bedrock_random_get_uint <- function(n, max) {
 #' Default range is `[0, 2^31-1]`.
 #
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_get_int
 #' @export
 bedrock_random_get_int <- function(n, min, max) {
-    n <- as.integer(n)
-    if (!missing(min) && missing(max)) {
-        max <- min
-        min <- NULL
-    } else {
-        if (missing(min)) {
-            min <- NULL
-        }
-        if (missing(max)) {
-            max <- NULL
-        }
+  n <- as.integer(n)
+  if (!missing(min) && missing(max)) {
+    max <- min
+    min <- NULL
+  } else {
+    if (missing(min)) {
+      min <- NULL
     }
+    if (missing(max)) {
+      max <- NULL
+    }
+  }
 
-    .Call(Cmcpe_random_get_int, n, min, max)
+  .Call(R_mcpe_random_get_int, n, min, max)
 }
 
 #' @description
@@ -88,22 +92,23 @@ bedrock_random_get_int <- function(n, min, max) {
 #' Default range is `[0.0, 1.0)`.
 #
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_get_float
 #' @export
 bedrock_random_get_float <- function(n, min, max) {
-    n <- as.integer(n)
-    if (!missing(min) && missing(max)) {
-        max <- min
-        min <- NULL
-    } else {
-        if (missing(min)) {
-            min <- NULL
-        }
-        if (missing(max)) {
-            max <- NULL
-        }
+  n <- as.integer(n)
+  if (!missing(min) && missing(max)) {
+    max <- min
+    min <- NULL
+  } else {
+    if (missing(min)) {
+      min <- NULL
     }
+    if (missing(max)) {
+      max <- NULL
+    }
+  }
 
-    .Call(Cmcpe_random_get_float, n, min, max)
+  .Call(R_mcpe_random_get_float, n, min, max)
 }
 
 #' @description
@@ -111,10 +116,11 @@ bedrock_random_get_float <- function(n, min, max) {
 #' Default range is `[0.0, 1.0)`.
 #'
 #' @rdname bedrock_random
+#' @useDynLib rbedrock R_mcpe_random_get_double
 #' @export
 bedrock_random_get_double <- function(n) {
-    n <- as.integer(n)
-    .Call(Cmcpe_random_get_double, n)
+  n <- as.integer(n)
+  .Call(R_mcpe_random_get_double, n)
 }
 
 #' Random Number Seeds for Minecraft
@@ -122,7 +128,9 @@ bedrock_random_get_double <- function(n) {
 #' Minecraft uses several different kind of seeds during world generation and
 #' gameplay.
 #'
-#' @name bedrock_random_create_seed
+#' `bedrock_random_create_seed()` constructs a seed using the formulas
+#' type 1: `x*a ^ z*b ^ salt`, type 2: `x*a + z*b + salt`, and type 3:
+#' `x*a + z*b ^ salt`.
 #'
 #' @param x,z chunk coordinates
 #' @param a,b seed parameters
@@ -131,25 +139,21 @@ bedrock_random_get_double <- function(n) {
 #'
 #' @examples
 #' # identify slime chunks
-#' g <- tidyr::expand_grid(x=1:10, z=1:10)
-#' is_slime_chunk <- purrr::pmap_lgl(g, function(x,z) {
+#' g <- expand.grid(x=1:10, z=1:10)
+#' is_slime_chunk <- mapply(g$x, g$z, FUN = function(x,z) {
 #'   seed <- bedrock_random_create_seed(x,z,0x1f1f1f1f,1,0,type=1)
 #'   bedrock_random_seed(seed)
 #'   bedrock_random_get_uint(1,10) == 0
 #' })
-
-#' @description
-#' `bedrock_random_create_seed()` constructs a seed using the formulas
-#' type 1: `x*a ^ z*b ^ salt`, type 2: `x*a + z*b + salt`, and type 3:
-#' `x*a + z*b ^ salt`.
 #'
+#' @useDynLib rbedrock R_mcpe_random_create_seed
 #' @export
 bedrock_random_create_seed <- function(x, z, a, b, salt, type) {
-    x <- as.integer(x)
-    z <- as.integer(z)
-    a <- as.integer(a)
-    b <- as.integer(b)
-    salt <- as.integer(salt)
-    type <- as.integer(type)
-    .Call(Cmcpe_random_create_seed, x, z, a, b, salt, type)
+  x <- as.integer(x)
+  z <- as.integer(z)
+  a <- as.integer(a)
+  b <- as.integer(b)
+  salt <- as.integer(salt)
+  type <- as.integer(type)
+  .Call(R_mcpe_random_create_seed, x, z, a, b, salt, type)
 }
