@@ -1,23 +1,12 @@
 #' @details
 #' rbedrock is currently under development.
 #' @keywords internal
-#' @import vctrs
 #' @import rlang
-#' @import stringr
 "_PACKAGE"
 
-#' Pipe operator
-#'
-#' @name %>%
-#' @rdname op-pipe
-#' @keywords internal
-#' @export
-#' @importFrom magrittr %>%
-#' @usage lhs \%>\% rhs
-NULL
-
 # The following block is used by usethis to automatically manage
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
+#' @importFrom R6 R6Class
 ## usethis namespace: end
 NULL
