@@ -20,9 +20,12 @@
 # SOFTWARE.
 */
 
-#include <R.h>
-#include <Rinternals.h>
-#include <stdbool.h>
+#ifndef FRAGMITES_ACTORS_H
+#define FRAGMITES_ACTORS_H
 
-SEXP rbedrock_actor_make_uniqueids(SEXP low_counter, SEXP high_counter);
-SEXP rbedrock_actor_make_storagekeys(SEXP ids);
+#include <Rinternals.h>
+
+SEXP R_rbedrock_actor_make_uniqueids(SEXP low_counter, SEXP high_counter);
+SEXP R_rbedrock_actor_make_storagekeys(SEXP ids);
+
+#endif
